@@ -5,7 +5,7 @@ from threading import Event
 import time
 
 
-sio = socketio.Client()
+sio = socketio.Client(ssl_verify=False)
 resolveHandlers = {}
 
 
